@@ -41,13 +41,12 @@ class NavModel(BaseModel):
 
     
 class AccountModel(BaseModel):
-    id: UUID
-    name: str
-    tags: str
-    navs: Optional[List[NavModel]]
+    id: Optional[UUID] = None
+    name: Optional[str] = None
+    navs: Optional[List[NavModel]] = None
     uix: dict
-    tags: str
-    is_active: bool
-    created_at: datetime
-    updated_at: datetime
+    tags: Optional[str] = None
+    is_active: bool = False
+    created_at: Optional[datetime] = None
+    updated_at: Optional[datetime] = None
     
\ No newline at end of file
