@@ -1,4 +1,4 @@
-from typing import Optional, Union
+from typing import Optional, List
 from uuid import UUID
 from pydantic import BaseModel
 
@@ -31,10 +31,10 @@ class ContextModel(BaseModel):
     is_active: bool
     location: LocationModel
     nation: NationModel
-    user: Optional[UserModel]
+    user: Optional[UserModel] = None
     page: PageModel
+    navs: Optional[List[NavModel]]
     uix: dict
-    navs: Union[list[NavModel], None]
     root: str
     
     
\ No newline at end of file
