@@ -25,12 +25,10 @@ class ContextService:
         
         user_model = UserService(req=self.req)
         user_data = user_model.app()
-    
-        account_data = None
-        if user_data:
-            account_model = AccountService(req=self.req, session_key=page_data.root, application_id=app_data.id)
-            account_data = account_model.get()
-    
+
+        account_model = AccountService(req=self.req, session_key=page_data.root, application_id=app_data.id)
+        account_data = account_model.get()
+
         location_model = LocationService(req=self.req, session_key=page_data.root)
         location_data = location_model.get()
         
@@ -42,19 +40,14 @@ class ContextService:
         
         data = {
             **app_data.__dict__,
-            "page": page_data.__dict__,
-            "location": location_data.__dict__,
-            "user_agent": user_agent_data.__dict__,
-            "root": page_data.root
+            'page': page_data.__dict__,
+            'location': location_data.__dict__,
+            'user_agent': user_agent_data.__dict__,
+            'navs': account_data.navs if account_data.navs else None,
+            'uix': account_data.uix,
+            'nation': nation_data.__dict__,
+            'user': user_data.__dict__ if user_data else None,
+            'root': page_data.root,
         }
         
-        if user_data:
-            data["user"] = user_data.__dict__
-        
-        if account_data:
-            data["account"] = account_data.__dict__
-            
-        if nation_data:
-            data["nation"] = nation_data.__dict__
-            
         return ContextModel(**data)
\ No newline at end of file
